@@ -25,7 +25,7 @@ head(dar.comparisons)
 win.matrix <- BSBT::comparisons_to_matrix(452, dar.comparisons)
 
 ## -----------------------------------------------------------------------------
-k <- constrained_adjacency_covariance_function(dar.adj.matrix, type = "matrix", hyperparameters = c(1), linear.combination = rep(1, 452), linear.constraint = 0)
+k <- constrained_adjacency_covariance_function(dar.adj.matrix, type = "matrix", hyperparameters = c(1, 1), linear.combination = rep(1, 452), linear.constraint = 0)
 
 ## -----------------------------------------------------------------------------
 data("mean.deprivation")
@@ -68,7 +68,7 @@ for(j in 1:dim(female.comparisons)[1])
   female.win.matrix[female.comparisons[j, 1], female.comparisons[j, 2]] <- female.win.matrix[female.comparisons[j, 1], female.comparisons[j, 2]] + 1
 
 ## -----------------------------------------------------------------------------
-k <- constrained_adjacency_covariance_function(dar.adj.matrix, type = "sqexp", hyperparameters = c(1, 0.5), linear.combination = rep(1, 452), linear.constraint = 0)
+k <- constrained_adjacency_covariance_function(dar.adj.matrix, type = "matrix", hyperparameters = c(1, 1), linear.combination = rep(1, 452), linear.constraint = 0)
 
 ## -----------------------------------------------------------------------------
 data("male.mean.deprivation")
